==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/VMwareToAzStackHCINicInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCINicInputArgs.builder
import com.pulumi.azurenative.datareplication.kotlin.enums.VMNicSelection
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VMwareToAzStackHCI NIC properties.
 * @property label Gets or sets the NIC label.
 * @property nicId Gets or sets the NIC Id.
 * @property selectionTypeForFailover Gets or sets the selection type of the NIC.
 * @property targetNetworkId Gets or sets the target network Id within AzStackHCI Cluster.
 * @property testNetworkId Gets or sets the target test network Id within AzStackHCI Cluster.
 */
public data class VMwareToAzStackHCINicInputArgs(
    public val label: Output<String>,
    public val nicId: Output<String>,
    public val selectionTypeForFailover: Output<Either<String, VMNicSelection>>,
    public val targetNetworkId: Output<String>,
    public val testNetworkId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCINicInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCINicInputArgs =
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCINicInputArgs.builder()
            .label(label.applyValue({ args0 -> args0 }))
            .nicId(nicId.applyValue({ args0 -> args0 }))
            .selectionTypeForFailover(
                selectionTypeForFailover.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .targetNetworkId(targetNetworkId.applyValue({ args0 -> args0 }))
            .testNetworkId(testNetworkId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VMwareToAzStackHCINicInputArgs].
 */
@PulumiTagMarker
public class VMwareToAzStackHCINicInputArgsBuilder internal constructor() {
    private var label: Output<String>? = null

    private var nicId: Output<String>? = null

    private var selectionTypeForFailover: Output<Either<String, VMNicSelection>>? = null

    private var targetNetworkId: Output<String>? = null

    private var testNetworkId: Output<String>? = null

    /**
     * @param value Gets or sets the NIC label.
     */
    @JvmName("drowlmovqkwtmgyh")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value Gets or sets the NIC Id.
     */
    @JvmName("iwxtnrdmxvlarspi")
    public suspend fun nicId(`value`: Output<String>) {
        this.nicId = value
    }

    /**
     * @param value Gets or sets the selection type of the NIC.
     */
    @JvmName("tcdglkyojhvnrprf")
    public suspend fun selectionTypeForFailover(`value`: Output<Either<String, VMNicSelection>>) {
        this.selectionTypeForFailover = value
    }

    /**
     * @param value Gets or sets the target network Id within AzStackHCI Cluster.
     */
    @JvmName("mkhdhfgolhidsppj")
    public suspend fun targetNetworkId(`value`: Output<String>) {
        this.targetNetworkId = value
    }

    /**
     * @param value Gets or sets the target test network Id within AzStackHCI Cluster.
     */
    @JvmName("fofqvhhogpteblwx")
    public suspend fun testNetworkId(`value`: Output<String>) {
        this.testNetworkId = value
    }

    /**
     * @param value Gets or sets the NIC label.
     */
    @JvmName("qsgtmqabuicmxlli")
    public suspend fun label(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value Gets or sets the NIC Id.
     */
    @JvmName("svqkqghkcfsarjva")
    public suspend fun nicId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nicId = mapped
    }

    /**
     * @param value Gets or sets the selection type of the NIC.
     */
    @JvmName("kruvqmlgjlauihhi")
    public suspend fun selectionTypeForFailover(`value`: Either<String, VMNicSelection>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectionTypeForFailover = mapped
    }

    /**
     * @param value Gets or sets the selection type of the NIC.
     */
    @JvmName("daodykyauobxvhrm")
    public fun selectionTypeForFailover(`value`: String) {
        val toBeMapped = Either.ofLeft<String, VMNicSelection>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectionTypeForFailover = mapped
    }

    /**
     * @param value Gets or sets the selection type of the NIC.
     */
    @JvmName("pfopviujeppycggs")
    public fun selectionTypeForFailover(`value`: VMNicSelection) {
        val toBeMapped = Either.ofRight<String, VMNicSelection>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectionTypeForFailover = mapped
    }

    /**
     * @param value Gets or sets the target network Id within AzStackHCI Cluster.
     */
    @JvmName("wanagbmfsxgrwaap")
    public suspend fun targetNetworkId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetNetworkId = mapped
    }

    /**
     * @param value Gets or sets the target test network Id within AzStackHCI Cluster.
     */
    @JvmName("iqtfgwkadvgyorat")
    public suspend fun testNetworkId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.testNetworkId = mapped
    }

    internal fun build(): VMwareToAzStackHCINicInputArgs = VMwareToAzStackHCINicInputArgs(
        label = label ?: throw PulumiNullFieldException("label"),
        nicId = nicId ?: throw PulumiNullFieldException("nicId"),
        selectionTypeForFailover = selectionTypeForFailover ?: throw
            PulumiNullFieldException("selectionTypeForFailover"),
        targetNetworkId = targetNetworkId ?: throw PulumiNullFieldException("targetNetworkId"),
        testNetworkId = testNetworkId ?: throw PulumiNullFieldException("testNetworkId"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/VMwareToAzStackHCINicInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCINicInputArgs.builder
import com.pulumi.azurenative.datareplication.kotlin.enums.VMNicSelection
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VMwareToAzStackHCI NIC properties.
 * @property label Gets or sets the NIC label.
 * @property nicId Gets or sets the NIC Id.
 * @property selectionTypeForFailover Gets or sets the selection type of the NIC.
 * @property targetNetworkId Gets or sets the target network Id within AzStackHCI Cluster.
 * @property testNetworkId Gets or sets the target test network Id within AzStackHCI Cluster.
 */
public data class VMwareToAzStackHCINicInputArgs(
    public val label: Output<String>,
    public val nicId: Output<String>,
    public val selectionTypeForFailover: Output<Either<String, VMNicSelection>>,
    public val targetNetworkId: Output<String>,
    public val testNetworkId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCINicInputArgs> {
    override fun toJava():
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCINicInputArgs =
        com.pulumi.azurenative.datareplication.inputs.VMwareToAzStackHCINicInputArgs.builder()
            .label(label.applyValue({ args0 -> args0 }))
            .nicId(nicId.applyValue({ args0 -> args0 }))
            .selectionTypeForFailover(
                selectionTypeForFailover.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .targetNetworkId(targetNetworkId.applyValue({ args0 -> args0 }))
            .testNetworkId(testNetworkId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VMwareToAzStackHCINicInputArgs].
 */
@PulumiTagMarker
public class VMwareToAzStackHCINicInputArgsBuilder internal constructor() {
    private var label: Output<String>? = null

    private var nicId: Output<String>? = null

    private var selectionTypeForFailover: Output<Either<String, VMNicSelection>>? = null

    private var targetNetworkId: Output<String>? = null

    private var testNetworkId: Output<String>? = null

    /**
     * @param value Gets or sets the NIC label.
     */
    @JvmName("hvmjlguyoogpxlje")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value Gets or sets the NIC Id.
     */
    @JvmName("ewyrnsfsdunbadvg")
    public suspend fun nicId(`value`: Output<String>) {
        this.nicId = value
    }

    /**
     * @param value Gets or sets the selection type of the NIC.
     */
    @JvmName("assccjcfsasnxqvg")
    public suspend fun selectionTypeForFailover(`value`: Output<Either<String, VMNicSelection>>) {
        this.selectionTypeForFailover = value
    }

    /**
     * @param value Gets or sets the target network Id within AzStackHCI Cluster.
     */
    @JvmName("mpxcnebychwelmvf")
    public suspend fun targetNetworkId(`value`: Output<String>) {
        this.targetNetworkId = value
    }

    /**
     * @param value Gets or sets the target test network Id within AzStackHCI Cluster.
     */
    @JvmName("ecgklipbgkchgtpu")
    public suspend fun testNetworkId(`value`: Output<String>) {
        this.testNetworkId = value
    }

    /**
     * @param value Gets or sets the NIC label.
     */
    @JvmName("gdpwgpmahyevpqek")
    public suspend fun label(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value Gets or sets the NIC Id.
     */
    @JvmName("tvysxprwkpcpkkri")
    public suspend fun nicId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nicId = mapped
    }

    /**
     * @param value Gets or sets the selection type of the NIC.
     */
    @JvmName("sewtjgbwlcmtafpw")
    public suspend fun selectionTypeForFailover(`value`: Either<String, VMNicSelection>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectionTypeForFailover = mapped
    }

    /**
     * @param value Gets or sets the selection type of the NIC.
     */
    @JvmName("oabxqbyoqdpppgll")
    public fun selectionTypeForFailover(`value`: String) {
        val toBeMapped = Either.ofLeft<String, VMNicSelection>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectionTypeForFailover = mapped
    }

    /**
     * @param value Gets or sets the selection type of the NIC.
     */
    @JvmName("mqcepemkyesfoold")
    public fun selectionTypeForFailover(`value`: VMNicSelection) {
        val toBeMapped = Either.ofRight<String, VMNicSelection>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.selectionTypeForFailover = mapped
    }

    /**
     * @param value Gets or sets the target network Id within AzStackHCI Cluster.
     */
    @JvmName("tfmncmioroldmcuk")
    public suspend fun targetNetworkId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targetNetworkId = mapped
    }

    /**
     * @param value Gets or sets the target test network Id within AzStackHCI Cluster.
     */
    @JvmName("wemggbdwtwtvusry")
    public suspend fun testNetworkId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.testNetworkId = mapped
    }

    internal fun build(): VMwareToAzStackHCINicInputArgs = VMwareToAzStackHCINicInputArgs(
        label = label ?: throw PulumiNullFieldException("label"),
        nicId = nicId ?: throw PulumiNullFieldException("nicId"),
        selectionTypeForFailover = selectionTypeForFailover ?: throw
            PulumiNullFieldException("selectionTypeForFailover"),
        targetNetworkId = targetNetworkId ?: throw PulumiNullFieldException("targetNetworkId"),
        testNetworkId = testNetworkId ?: throw PulumiNullFieldException("testNetworkId"),
    )
}
